if (Boolean(window.fansUnitedSettings.fans_united_firebase_anonymous_mode) === true) {
    // Attempt to sign in the user anonymously
    firebase.auth().signInAnonymously()
    .catch((error) => {
        console.error('Error during anonymous sign-in:', error);
    });
}


firebase.auth().onAuthStateChanged((user) => {
    if (user) {
        // User is signed in, update the token in local storage
        user.getIdToken().then(function(idToken) {
            localStorage.setItem('fans-united-id-token', idToken);
        });
    } else {
        // User is signed out, remove the token from local storage
        localStorage.removeItem('fans-united-id-token');
    }
});

let fuLang = fansUnitedSettings.fans_united_lang;
if(window.fansUnitedCurrentLanguage && window.fansUnitedCurrentLanguage !== 'default' && fansUnitedSettings.fans_united_lang !== '') {
    fuLang = window.fansUnitedCurrentLanguage;
}
window.FansUnitedSDK = FansUnitedSDK.FansUnitedSDK({
    apiKey: fansUnitedSettings.fans_united_api_key,
    clientId: fansUnitedSettings.fans_united_client_id,
    idSchema: fansUnitedSettings.fans_united_id_provider ?? "native",
    environment:fansUnitedSettings.fans_united_env ?? "prod",
    lang: fuLang,
    errorHandlingMode: "standard",
    authProvider: {
        getIdToken: getIdToken,
        logout: () => {}
    }
});

function getIdToken() {
    // Get token from local storage
    const idToken = localStorage.getItem('fans-united-id-token');
    
    // Check if there's a token in local storage
    if (!idToken) {
        // No token in local storage, return empty string
        return '';
    }

    // Return the token
    return idToken;
}

/**
 * Sign in with Firebase email & pass
 */
document.addEventListener('DOMContentLoaded', function() {
    // Get form elements
    const form = document.getElementById('fansunited-firebase-login-form');
    const emailInput = document.getElementById('fansunited-firebase-login-email');
    const passwordInput = document.getElementById('fansunited-firebase-login-password');

    // Attach submit event listener to form
    if (form !== null) {
        form.addEventListener('submit', function(event) {
            // Prevent form from submitting normally
            event.preventDefault();

            // Get email and password
            const email = emailInput.value;
            const password = passwordInput.value;
            const submitButton = event.submitter;

            // add loading button
            submitButton.classList.add('fans-united-loading-button');

            // Sign in with Firebase
            firebase.auth().signInWithEmailAndPassword(email, password)
                .then(function(result) {
                    // User signed in successfully

                    // Get the ID token and refresh token
                    return result.user.getIdToken();
                })
                .then(function(idToken) {
                    // Save tokens in local storage with prefix
                    localStorage.setItem('fans-united-id-token', idToken);
                    
                    // Make an API request to your WordPress endpoint
                    return fetch('/wp-json/fans-united/v1/sync', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                            'Accept': 'application/json'
                        },
                        body: JSON.stringify({
                            token: idToken
                        })
                    });
                })
                .then(function(response) {
                    // Check if API call was successful
                    if (response.ok) {
                        // remove loading class
                        submitButton.classList.remove('fans-united-loading-button');

                        // Redirect to homepage
                        window.location.href = '/';
                    } else {
                        // remove class
                        submitButton.classList.remove('fans-united-loading-button');
                        throw new Error("Failed to authenticate with WordPress");
                    }
                })
                .catch(function(error) {
                    // remove class
                    submitButton.classList.remove('fans-united-loading-button');
                    toastr.error(getFansUnitedLabel('auth_login_error'));
                    console.error("Error:", error);
                });
        });
    }
});



/**
 * Registration with Firebase email & pass
 */
document.addEventListener('DOMContentLoaded', function() {
    // Get form elements
    const form = document.getElementById('fansunited-firebase-registration-form');
    const nameInput = document.getElementById('fansunited-firebase-registration-name');
    const emailInput = document.getElementById('fansunited-firebase-registration-email');
    const passwordInput = document.getElementById('fansunited-firebase-registration-password');
    const confirmPasswordInput = document.getElementById('fansunited-firebase-registration-confirm-password');

    // Attach submit event listener to form
    if (form !== null) {
        form.addEventListener('submit', function(event) {
            // Prevent form from submitting normally
            event.preventDefault();

            // Get name, email, password, and confirm password
            const name = nameInput.value;
            const email = emailInput.value;
            const password = passwordInput.value;
            const confirmPassword = confirmPasswordInput.value;
            const submitButton = event.submitter;

            // add loading button
            submitButton.classList.add('fans-united-loading-button');

            // Check if passwords match
            if (password !== confirmPassword) {
                // remove loading class
                submitButton.classList.remove('fans-united-loading-button');
                toastr.error(getFansUnitedLabel('auth_register_error_passwords_match'));
                return;
            }

            // Create user with email and password
            firebase.auth().createUserWithEmailAndPassword(email, password)
                .then(function(result) {
                    // User registered successfully
                    // console.log(result);
            
                    // Set user display name
                    return result.user.updateProfile({
                        displayName: name
                    });
                })
                .then(function() {
                    // Display name set successfully
                    // console.log('Display name set');
            
                    // Return the current user
                    return firebase.auth().currentUser;
                })
                .then(function(user) {
                    // Get the ID token and refresh token
                    return user.getIdToken(true);
                })
                .then(function(idToken) {
                    // Save tokens in local storage with prefix
                    localStorage.setItem('fans-united-id-token', idToken);

                    // Make an API request to your WordPress endpoint
                    return fetch('/wp-json/fans-united/v1/sync', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                            'Accept': 'application/json'
                        },
                        body: JSON.stringify({
                            token: idToken,
                            password: password
                        })
                    });
                })
                .then(function(response) {
                    // Check if API call was successful
                    if (response.ok) {
                        // remove loading class
                        submitButton.classList.remove('fans-united-loading-button');
                        // Redirect to homepage
                        window.location.href = '/';
                    } else {
                        // remove loading class
                        submitButton.classList.remove('fans-united-loading-button');
                        throw new Error("Failed to authenticate with WordPress");
                    }
                })
                .catch(function(error) {
                    // remove loading class
                    submitButton.classList.remove('fans-united-loading-button');
                    toastr.error(getFansUnitedLabel('auth_register_error'));
                });
        });
    }
});


/**
 * Reset password with Firebase
 */
document.addEventListener('DOMContentLoaded', function() {
    // Get form elements
    const form = document.getElementById('fansunited-firebase-forgotten-password-form');
    const emailInput = document.getElementById('fansunited-firebase-forgotten-password-email');

    // Attach submit event listener to form
    if (form !== null) {
        form.addEventListener('submit', function(event) {
            // Prevent form from submitting normally
            event.preventDefault();
            
            // Get email
            const email = emailInput.value;
            const submitButton = event.submitter;

            // add loading button
            submitButton.classList.add('fans-united-loading-button');

            // Send password reset email with Firebase
            firebase.auth().sendPasswordResetEmail(email)
                .then(function() {
                    submitButton.remove();
                    toastr.success(getFansUnitedLabel('auth_forgotten_password_email_sent'));
                })
                .catch(function(error) {
                    submitButton.classList.remove('fans-united-loading-button');
                    toastr.error(getFansUnitedLabel('auth_forgotten_password_failed_email'));
                });
        });
    }
});

/**
 * Function to sign users out
 */
function fansUnitedLogOutWithFirebase() {
    firebase.auth().signOut()
        .then(function() {
            // Logout successful
            // Clear local storage
            localStorage.removeItem('fans-united-id-token');
            localStorage.removeItem('FansUnited');
            // Redirect to desired page or perform any additional actions
            window.location.href = '/'; // Redirect to homepage
        })
        .then(() => {
            // Make an API request to your WordPress endpoint
            return fetch('/wp-json/fans-united/v1/sign-out', {
                method: 'GET',
                headers: {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json'
                }
            });
        })
        .then(function(response) {
            // Check if API call was successful
            if (response.ok) {
                // Redirect to homepage
                window.location.href = '/';
            } else {
                throw new Error("Failed to sign out from WordPress");
            }
        })
        .catch(function(error) {
            console.error('Logout error:', error);
        });
}

document.addEventListener('DOMContentLoaded', function() {
    const observer = new MutationObserver(function(mutationsList) {
        for (let mutation of mutationsList) {
            if (mutation.type === 'childList') {
                const logoutButton = document.getElementById('fans-united-logout-button-for-firebase');
                if (logoutButton) {
                    logoutButton.addEventListener('click', function(event) {
                        event.preventDefault();
                        fansUnitedLogOutWithFirebase();
                    });
                    observer.disconnect();  // stop observing once the button is found and event is attached
                }
            }
        }
    });
    observer.observe(document.body, { childList: true, subtree: true });
});



/**
 * Sign in with social logins via Firebase
 */
document.addEventListener('DOMContentLoaded', function(event) {
    // Get Firebase auth instance
    var auth = firebase.auth();

    // Get sign-in button elements
    var googleLoginButton = document.querySelector('.fans-united-google-login');
    var facebookLoginButton = document.querySelector('.fans-united-facebook-login');

    // Function to handle successful sign-in
    function handleSignInResult(user) {
        // User is signed in, update the token in local storage
        user.getIdToken()
        .then(function(idToken) {
            // Save tokens in local storage with prefix
            localStorage.setItem('fans-united-id-token', idToken);

            // Make an API request to your WordPress endpoint
            return fetch('/wp-json/fans-united/v1/sync', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json'
                },
                body: JSON.stringify({
                    token: idToken
                })
            });
        })
        .then(function(response) {
            // Check if API call was successful
            if (response.ok) {
                // Redirect to homepage
                window.location.href = '/';
            } else {
                throw new Error("Failed to authenticate with WordPress");
            }
        });
    }

    // Attach click event listeners
    if(googleLoginButton) {
        googleLoginButton.addEventListener('click', function() {
            // Create a new Google auth provider
            var provider = new firebase.auth.GoogleAuthProvider();
            // Start sign-in process
            auth.signInWithPopup(provider)
                .then(function(result) {
                    handleSignInResult(result.user);
                })
                .catch(function(error) {
                    console.error('Google sign-in error:', error);
                });
        });
    }

    if(facebookLoginButton) {
        facebookLoginButton.addEventListener('click', function() {
            // Create a new Facebook auth provider
            var provider = new firebase.auth.FacebookAuthProvider();
            // Start sign-in process
            auth.signInWithPopup(provider)
                .then(function(result) {
                    handleSignInResult(result.user);
                })
                .catch(function(error) {
                    console.error('Facebook sign-in error:', error);
                });
        });
    }
});
