import { createRoot } from 'react-dom/client';

import '../../assets/scss/style.scss';

import TopXComponent from '../../src/top-x/TopXComponent';
import Profile from '../../src/profile/Profile';
import MatchQuizComponent from '../../src/match-quiz/MatchQuizComponent';
import LeaderboardComponent from '../../src/leaderboard/LeaderboardComponent';
import TopPredictionsComponent from '../../src/top-predictions/TopPredictionsComponent';
import PredictionThreeWayComponent from '../../src/prediction-three-way/PredictionThreeWayComponent';
import PredictionYesNoComponent from '../../src/prediction-yes-no/PredictionYesNoComponent';
import PredictionCorrectScoreComponent from '../../src/prediction-correct-score/PredictionCorrectScoreComponent';
import PredictionDoubleChanceComponent from '../../src/prediction-double-chance/PredictionDoubleChanceComponent';
import PredictionHtFtComponent from '../../src/prediction-ht-ft/PredictionHtFtComponent';
import PredictionThreeWayNextMatchComponent from '../../src/prediction-three-way-next-match/PredictionThreeWayNextMatchComponent';
import PredictionCorrectScoreNextMatchComponent from '../../src/prediction-correct-score-next-match/PredictionCorrectScoreNextMatchComponent';
import PredictionYesNoNextMatchComponent from '../../src/prediction-yes-no-next-match/PredictionYesNoNextMatchComponent';
import PredictionDoubleChanceNextMatchComponent from '../../src/prediction-double-chance-next-match/PredictionDoubleChanceNextMatchComponent';
import PredictionHtFtNextMatchComponent from '../../src/prediction-ht-ft-next-match/PredictionHtFtNextMatchComponent';
import PredictionCenterComponent from '../../src/prediction-center/PredictionCenterComponent';
import PredictionCenterNextMatchComponent from '../../src/prediction-center-next-match/PredictionCenterNextMatchComponent';
import PredictionPlayerNextMatchComponent from '../../src/prediction-player-next-match/PredictionPlayerNextMatchComponent';
import PredictionCenterPlayerNextMatchComponent from '../../src/prediction-center-player-next-match/PredictionCenterPlayerNextMatchComponent';
import TopXManagementWrapper from '../../src/admin/TopXManagementWrapper';
import LeaderboardManagementWrapper from '../../src/admin/LeaderboardManagementWrapper';
import MatchQuizManagementWrapper from '../../src/admin/MatchQuizManagementWrapper';
import ManagementWrapper from '../../src/admin/ManagementWrapper';
import PublicProfile from '../../src/profile/PublicProfile';
import PredictionPlayer from '../../src/prediction-player/PredictionPlayerComponent';
import GameRankings from '../../src/admin/GameRanings';
import TopXLinkComponent from '../../src/top-x-link/TopXLinkComponent';
import MatchQuizLinkComponent from '../../src/match-quiz-link/MatchQuizLinkComponent';
import LeaderboardLinkComponent from '../../src/leaderboard-link/LeaderboardLinkComponent';
import ClassicQuizComponent from '../../src/classic-quiz/ClassicQuizComponent';
import CassicQuizzesListComponent from '../../src/classic-quizzes-list/CassicQuizzesListComponent';
import ClassicQuizManagementWrapper from '../../src/admin/ClassicQuizManagementWrapper';
import DiscussionsManagementWrapper from '../../src/admin/DiscussionsManagementWrapper';
import LeaderboardRankingComponent from '../../src/leaderboard-ranking/LeaderboardRankingComponent';

/**
 * Frontend components
 */
const rootElements = document.querySelectorAll('[data-component]');
rootElements.forEach((rootElement) => {
    const root = createRoot(rootElement);
    
    const componentType = rootElement.getAttribute('data-component');
    const id = rootElement.getAttribute('data-id');
    const profileId = rootElement.getAttribute('data-profile-id');
    const matchId = rootElement.getAttribute('data-match-id');
    const teamId = rootElement.getAttribute('data-team-id');
    const playerId = rootElement.getAttribute('data-player-id');
    const competitionId = rootElement.getAttribute('data-competition-id');
    const market = rootElement.getAttribute('data-market');
    const flags = rootElement.getAttribute('data-flags');
    const entities = rootElement.getAttribute('data-entities');
    const entityType = rootElement.getAttribute('data-entity-type');
    const replaceMeta = Boolean(rootElement.getAttribute('data-replace-meta')) ?? false;

    switch (componentType) {
        case 'top-x':
            root.render(<TopXComponent id={id} replaceMeta={replaceMeta} />);
            break;
        case 'top-x-link':
            root.render(<TopXLinkComponent id={id} />);
            break;
        case 'match-quiz':
            root.render(<MatchQuizComponent id={id} replaceMeta={replaceMeta} />);
            break;
        case 'classic-quiz':
            root.render(<ClassicQuizComponent id={id} replaceMeta={replaceMeta} />);
            break;
        case 'classic-quizzes-list':
            root.render(<CassicQuizzesListComponent flags={flags} entities={entities} entityType={entityType} replaceMeta={replaceMeta} />);
            break;
        case 'match-quiz-link':
            root.render(<MatchQuizLinkComponent id={id} />);
            break;
        case 'leaderboard':
            root.render(<LeaderboardComponent id={id} replaceMeta={replaceMeta} />);
            break;
        case 'leaderboard-ranking':
            root.render(<LeaderboardRankingComponent id={id} replaceMeta={replaceMeta} />);
            break;
        case 'leaderboard-link':
            root.render(<LeaderboardLinkComponent id={id} />);
            break;
        case 'user-profile':
            root.render(<Profile id={id} />);
            break;
        case 'public-profile':
            root.render(<PublicProfile id={id} profileId={profileId} />);
            break;
        case 'top-predictions':
            root.render(<TopPredictionsComponent id={id} competitionId={competitionId} />);
            break;
        case 'prediction-three-way':
            root.render(<PredictionThreeWayComponent key={`parent-three-way-${matchId}-${market}`} id={id} matchId={matchId} market={market} />);
            break;
        case 'prediction-three-way-next-match':
            root.render(<PredictionThreeWayNextMatchComponent key={`parent-three-way-${teamId}-${market}`} id={id} teamId={teamId} market={market} />);
            break;
        case 'prediction-yes-no':
            root.render(<PredictionYesNoComponent key={`parent-yes-no-${matchId}-${market}`} id={id} matchId={matchId} market={market} />);
            break;
        case 'prediction-yes-no-next-match':
            root.render(<PredictionYesNoNextMatchComponent key={`parent-yes-no-next-match-${teamId}-${market}`} id={id} teamId={teamId} market={market} />);
            break;
        case 'prediction-correct-score':
            root.render(<PredictionCorrectScoreComponent key={`parent-correct-score-${matchId}-${market}`} id={id} matchId={matchId} market={market} />);
            break;
        case 'prediction-correct-score-next-match':
            root.render(<PredictionCorrectScoreNextMatchComponent key={`parent-correct-score-next-match-${teamId}-${market}`} id={id} teamId={teamId} market={market} />);
            break;
        case 'prediction-double-chance':
            root.render(<PredictionDoubleChanceComponent key={`parent-double-chance-${matchId}`} id={id} matchId={matchId} market={'DOUBLE_CHANCE'} />);
            break;
        case 'prediction-double-chance-next-match':
            root.render(<PredictionDoubleChanceNextMatchComponent key={`parent-double-chance-next-match-${teamId}`} id={id} teamId={teamId} market={'DOUBLE_CHANCE'} />);
            break;
        case 'prediction-ht-ft':
            root.render(<PredictionHtFtComponent key={`parent-ht-ft-${matchId}`} id={id} matchId={matchId} market={'HT_FT'} />);
            break;
        case 'prediction-ht-ft-next-match':
            root.render(<PredictionHtFtNextMatchComponent key={`parent-ht-ft-next-match-${teamId}`} id={id} teamId={teamId} market={'HT_FT'} />);
            break;
        case 'prediction-center':
            root.render(<PredictionCenterComponent key={`parent-center-${matchId}`} id={id} matchId={matchId} />);
            break;
        case 'prediction-center-next-match':
            root.render(<PredictionCenterNextMatchComponent key={`parent-center-next-match-${teamId}`} id={id} teamId={teamId} />);
            break;
        case 'prediction-player-next-match':
            root.render(<PredictionPlayerNextMatchComponent key={`parent-player-next-match-${playerId}-${market}`} id={id} playerId={playerId} market={market} />);
            break;
        case 'prediction-center-player-next-match':
            root.render(<PredictionCenterPlayerNextMatchComponent key={`parent-center-player-next-match-${playerId}`} id={id} playerId={playerId} />);
            break;
        case 'prediction-player':
            root.render(<PredictionPlayer key={`parent-player-${playerId}-${market}-${matchId}`} id={id} playerId={playerId} market={market} matchId={matchId} />);
            break;
        default:
            break;
    }
});


/**
 * Admin components
 */
const rootManagementElements = document.querySelectorAll('[data-management-widget]');
rootManagementElements.forEach((rootElement) => {
    const root = createRoot(rootElement);
    
    const componentType = rootElement.getAttribute('data-management-widget');
    switch (componentType) {
        case 'top-x-management':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Top X Management</h1>
                    <TopXManagementWrapper  />
                </div>
            </>);
            break;
        case 'match-quiz-management':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Match Quiz Management</h1>
                    <MatchQuizManagementWrapper  />
                </div>
            </>);
            break;
        case 'leaderboards-management':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Leaderboards Management</h1>
                    <LeaderboardManagementWrapper  />
                </div>
            </>);
            break;
        case 'classic-quiz-management':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Classic Quizzes</h1>
                    <ClassicQuizManagementWrapper />
                </div>
            </>);
            break;
        case 'discussions-management':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Discussions</h1>
                    <DiscussionsManagementWrapper />
                </div>
            </>);
            break;
        case 'main-management-screen':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Welcome to Fans United Management</h1>
                    <ManagementWrapper  />
                </div>
            </>);
            break;
        case 'game-rankings':
            root.render(<>
                <div>
                    <h1 style={{fontSize: '23px', fontWeight: 400, margin: '20px 0', padding: '9px 0 4px', lineHeight: '1.3'}}>Game Rankings</h1>
                    <p>This page is only used if your Fans United integration runs in Anonymous Mode. Here you will be able to browse the rankings of the different games and check for winners.</p>
                    <GameRankings  />
                </div>
            </>);
            break;
        default:
            break;
    }
});
