
/**
 * Fetches a label
 */
getFansUnitedLabel = (key = '') => {
    return window.fansUnitedLabels[key] && window.fansUnitedLabels[key] !== '' ? window.fansUnitedLabels[key] : key;
}

/**
 * Fetches a path for a custom page
 */
getFansUnitedPath = (key = '') => {
    if(window.fansUnitedPaths[key] && window.fansUnitedPaths[key].configKey && 
        window.fansUnitedPaths[key].configKey !== '' && window.fansUnitedSettings[window.fansUnitedPaths[key].configKey] &&
        window.fansUnitedSettings[window.fansUnitedPaths[key].configKey] != ''
    ) {
        return window.fansUnitedSettings[window.fansUnitedPaths[key].configKey];
    } else {
        return window.fansUnitedPaths[key].defaultPath;
    }
}

/**
 * Updates avatar in Firebase and the Fans United profile
 */
setAvatarInFirebase = (avatarUrl, getUserProfile) => {

    let user = firebase.auth().currentUser;

    if (user) {
        // If you want to update a user's profile, for example:
        user.updateProfile({
            photoURL: avatarUrl
        }).then((r) => {
            // Profile in Firebase updated successfully
            // Updating profile in Fans United
            window.FansUnitedSDK.profile.getOwn().setAvatar(avatarUrl).update()
            .then(response => {
                toastr.success(getFansUnitedLabel("avatar_upload_success"));

                // fetch the profile so that the avatar is updated when the user goes back
                getUserProfile();
            }).catch(e => {
                console.warn("Error updating Fans United avatar");
            });
        }).catch((error) => {
            console.log(error.message);
        });
    } else {
        // No user is signed in.
        console.log('No user signed in');
    }
}

/**
 * Sets meta tags on page
 */
setMetaTags = (title, description) => {
    document.title = title;
    if(!document.title) {
        return false;
    }
  
    let metaOgTitle = document.querySelector('meta[property="og:title"]');
    if (metaOgTitle) {
        metaOgTitle.setAttribute('content', title);
    } else {
        metaOgTitle = document.createElement('meta');
        metaOgTitle.property = 'og:title';
        metaOgTitle.content = description;
        if(metaOgTitle && metaOgTitle.head) {
            metaOgTitle.head.appendChild(metaOgTitle);
        }
    }

    let metaDesc = document.querySelector('meta[name="description"]');
    if (metaDesc) {
        metaDesc.setAttribute('content', description);
    } else {
        // In case the meta description tag doesn't exist, create and append it
        metaDesc = document.createElement('meta');
        metaDesc.name = 'description';
        metaDesc.content = description;
        document.head.appendChild(metaDesc);
    }
}

/**
 * Formats date to the format 22.10 | 21:45
 */
formatDate = (dateString) => {
    const obj = new Date(dateString);
    const date = ('0' + obj.getDate()).slice(-2) + '.' + ('0' + (obj.getMonth()+1)).slice(-2);
    const time = ('0' + obj.getHours()).slice(-2) + ':' + ('0' + obj.getMinutes()).slice(-2);
    return date + ' | ' + time;
}

/**
 * Formats time to the format 21:45
 */
formatTime = (dateString) => {
    const obj = new Date(dateString);
    const time = ('0' + obj.getHours()).slice(-2) + ':' + ('0' + obj.getMinutes()).slice(-2);
    return time;
}

/**
 * Checks if too dates are on the same day
 */
isSameDay = (date1, date2) => {
    return date1.getFullYear() === date2.getFullYear() &&
           date1.getMonth() === date2.getMonth() &&
           date1.getDate() === date2.getDate();
}