<?php
/**
 * Plugin Name:       Fans United Integration
 * Description:       A plugin exposing Fans United functionality
 * Requires at least: 6.1
 * Requires PHP:      7.0
 * Version:           1.11.0
 * Author:            Fans United team
 * License:           GPL-2.0-or-later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       fans-united
 *
 * @package           fans-united
 */

require_once __DIR__ . '/vendor/autoload.php';

define('FANSUNITED_PLUGIN_URI', plugins_url() . '/' . basename(__DIR__) . '/');
define('FANSUNITED_PLUGIN_DIR', __DIR__ . '/');
define('FANSUNITED_PLUGIN_VERSION', '1.11.0');

 /**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */
function fansUnitedRegisterBlocks() {
    // Register block types
    register_block_type( __DIR__ . '/build/top-x', [
        'render_callback' => 'fansUnitedTopXRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/top-x-link', [
        'render_callback' => 'fansUnitedTopXLinkRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/match-quiz', [
        'render_callback' => 'fansUnitedMatchQuizRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/match-quiz-link', [
        'render_callback' => 'fansUnitedMatchQuizLinkRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/leaderboard', [
        'render_callback' => 'fansUnitedLeaderboardRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/leaderboard-ranking', [
        'render_callback' => 'fansUnitedLeaderboardRankingRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/leaderboard-link', [
        'render_callback' => 'fansUnitedLeaderboardLinkRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/top-predictions', [
        'render_callback' => 'fansUnitedTopPredictionsRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-three-way', [
        'render_callback' => 'fansUnitedPredictionThreeWayRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-three-way-next-match', [
        'render_callback' => 'fansUnitedPredictionThreeWayNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-yes-no', [
        'render_callback' => 'fansUnitedPredictionYesNoRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-yes-no-next-match', [
        'render_callback' => 'fansUnitedPredictionYesNoNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-correct-score', [
        'render_callback' => 'fansUnitedPredictionCorrectScoreRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-correct-score-next-match', [
        'render_callback' => 'fansUnitedPredictionCorrectScoreNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-double-chance', [
        'render_callback' => 'fansUnitedPredictionDoubleChanceRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-double-chance-next-match', [
        'render_callback' => 'fansUnitedPredictionDoubleChanceNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-ht-ft', [
        'render_callback' => 'fansUnitedPredictionHtFtRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-ht-ft-next-match', [
        'render_callback' => 'fansUnitedPredictionHtFtNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-center', [
        'render_callback' => 'fansUnitedPredictionCenterRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-center-next-match', [
        'render_callback' => 'fansUnitedPredictionCenterNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-player-next-match', [
        'render_callback' => 'fansUnitedPredictionPlayerNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-player-next-match', [
        'render_callback' => 'fansUnitedPredictionPlayerNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-center-player-next-match', [
        'render_callback' => 'fansUnitedPredictionCenterPlayerNextMatchRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/prediction-player', [
        'render_callback' => 'fansUnitedPredictionPlayerRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/tournament-predictor', [
        'render_callback' => 'fansUnitedTournamentPredictorRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/classic-quiz', [
        'render_callback' => 'fansUnitedClassicQuizRenderCallback'
    ]);
    register_block_type( __DIR__ . '/build/classic-quizzes-list', [
        'render_callback' => 'fansUnitedClassicQuizzesListRenderCallback'
    ]);
}
add_action( 'init', 'fansUnitedRegisterBlocks' );


// Include the settings and assets functionalities
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-labels.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-settings.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-assets.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-rendered-content.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-shortcodes.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-custom-pages.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-admin-pages.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-ajax.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-sql.php';
require_once plugin_dir_path(__FILE__) . 'includes/fans-united-templates.php';
