<?php

function get_fans_united_labels($lang = 'default') {
    // Retrieve the saved labels for all languages from the WordPress option
    $all_labels = get_option('fans_united_labels', []);

    // Get labels for the requested language or an empty array if not set
    $labels_for_lang = $all_labels[$lang] ?? [];

    // Merge the default labels with the fetched labels for the language, favoring the fetched labels
    $merged_labels = array_merge(FANSUNITED_DEFAULT_LABELS, $labels_for_lang);
    
    return $merged_labels;
}

function enqueue_my_scripts() {
    wp_enqueue_script('wp-api');
}
add_action('admin_enqueue_scripts', 'enqueue_my_scripts');


/**
 * Load Firebase from CDN
 */
function enqueue_external_scripts() {
    wp_enqueue_script('fans-united-firebase-app', 'https://www.gstatic.com/firebasejs/9.22.0/firebase-app-compat.js', [], '9.22.0', true);
    wp_enqueue_script('fans-united-firebase-auth', 'https://www.gstatic.com/firebasejs/9.22.0/firebase-auth-compat.js', ['fans-united-firebase-app'], '9.22.0', true);
    wp_enqueue_script('fusdkcdn', 'https://cdn.jsdelivr.net/npm/fansunited-sdk-umd@1.53.1/index.min.js', [], '1.x.x', true);
    wp_enqueue_script('fans-united-auth', FANSUNITED_PLUGIN_URI . 'assets/js/fans-united-auth.js', ['fusdkcdn', 'fans-united-firebase-app', 'fans-united-firebase-auth'], false, true);
    wp_enqueue_script('fans-united-helpers', FANSUNITED_PLUGIN_URI . 'assets/js/fans-united-helpers.js', ['fusdkcdn', 'fans-united-firebase-app', 'fans-united-firebase-auth', 'fans-united-auth'], false, true);
    wp_enqueue_script('toastrjs', 'https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js', ['fans-united-firebase-app'], '2.1.3', true);

    $fans_united_options = get_option('fans_united_options');

    // Detecting language
    $current_language = 'default'; // default language
    if($fans_united_options && $fans_united_options["fans_united_available_languages"]) {
        if (function_exists('wpml_current_language')) {
            $current_language = wpml_current_language();
        } elseif (function_exists('pll_current_language')) {
            $current_language = pll_current_language('slug');
        } else {
            $locale = get_locale();
            $current_language = substr($locale, 0, 2); // get first two characters from locale (en_US -> en)
        }
    }

    $data = 'window.fansUnitedSettings = ' . json_encode($fans_united_options) . ';';
    $fansUnitedLabels = 'window.fansUnitedLabels = ' . json_encode(get_fans_united_labels($current_language)) . ';';
    $fansUnitedCurrentLanguage = 'window.fansUnitedCurrentLanguage = "' . $current_language . '";';
    $firebaseInit = get_firebase_initialization_script();
    $styleString = overrideStyling($fans_united_options);
    $toastrOptions = toastrOptions();
    $constants = constants();
    wp_add_inline_script('fans-united-firebase-app', $data . $fansUnitedLabels .  $firebaseInit . $styleString . $constants . $fansUnitedCurrentLanguage, 'after');
    wp_add_inline_script('toastrjs', $toastrOptions, 'after');
}
add_action('wp_enqueue_scripts', 'enqueue_external_scripts');
add_action('admin_enqueue_scripts', 'enqueue_external_scripts');

function get_firebase_initialization_script() {
    return 'var firebaseConfig = {
            apiKey: fansUnitedSettings.fans_united_firebase_api_key,
            authDomain: fansUnitedSettings.fans_united_firebase_auth_domain,
            projectId: fansUnitedSettings.fans_united_firebase_project_id,
            storageBucket: fansUnitedSettings.fans_united_firebase_storage_bucket,
            messagingSenderId: fansUnitedSettings.fans_united_firebase_messaging_sender_id,
            appId: fansUnitedSettings.fans_united_firebase_app_id,
            measurementId: fansUnitedSettings.fans_united_firebase_measurement_id
        };
        // Initialize Firebase
        firebase.initializeApp(firebaseConfig);
    ';
}

function toastrOptions() {
    $toastrOptions = 'toastr.options.progressBar = true;';
    $toastrOptions .= 'toastr.options.closeButton = true;';
    return $toastrOptions;
}

function constants() {
    $constants = 'const fansUnitedPluginUrl = "' . FANSUNITED_PLUGIN_URI . '";';
    $constants .= 'window.ajaxurl = "'.admin_url('admin-ajax.php').'";';
    $constants .= 'window.uploadAvatarNonce = "'. wp_create_nonce( 'avatar-upload-nonce' ) .'";';
    $constants .= 'window.saveGameParticipationNonce = "'. wp_create_nonce( 'save-prediction-nonce' ) .'";';
    $constants .= '
        window.fansUnitedPaths = {
            profile: {
                defaultPath: "/fans-united-profile",
                configKey: "fans_united_profile_path",
            },
            publicProfile: {
                defaultPath: "/fans-united-public-profile?id=",
                configKey: "fans_united_public_profile_path",
            },
            register: {
                defaultPath: "/fans-united-register",
                configKey: "fans_united_firebase_register_path",
            },
            signin: {
                defaultPath: "/fans-united-signin",
                configKey: "fans_united_firebase_login_path",
            },
            forgottenPass: {
                defaultPath: "/fans-united-forgotten-password",
                configKey: "fans_united_firebase_forgotten_password_path",
            },
            topX: {
                defaultPath: "/fans-united-top-x?id=",
                configKey: "fans_united_top_x_path",
            },
            matchQuiz: {
                defaultPath: "/fans-united-match-quiz?id=",
                configKey: "fans_united_match_quiz_path",
            },
            leaderboard: {
                defaultPath: "/fans-united-leaderboard?id=",
                configKey: "fans_united_leaderboard_path",
            },
            classicQuiz: {
                defaultPath: "/fans-united-classic-quiz?id=",
                configKey: "fans_united_classic_quiz_path",
            }
        }
    ';
    return $constants;
}

function overrideStyling($fans_united_options) {

    $styleString = "";

    if(empty($fans_united_options)) {
        return $styleString;
    }

    $stylePropertyOptionMap = [
        // General Styles
        ["optionKey" => "fans_united_styling_primary_color", "styleProperty" => "--fu-light-primary-color"],
        ["optionKey" => "fans_united_styling_border_radius", "styleProperty" => "--fu-light-border-radius"],
        // Tab Styles
        ["optionKey" => "fans_united_styling_tab_bg_color", "styleProperty" => "--fu-light-tab-bg-color"],
        ["optionKey" => "fans_united_styling_tab_text_color", "styleProperty" => "--fu-light-tab-text-color"],
        ["optionKey" => "fans_united_styling_active_tab_bg_color", "styleProperty" => "--fu-light-active-tab-bg-color"],
        ["optionKey" => "fans_united_styling_active_tab_text_color", "styleProperty" => "--fu-light-active-tab-text-color"],
        ["optionKey" => "fans_united_styling_tab_content_bg_color", "styleProperty" => "--fu-light-tab-content-bg-color"],
        ["optionKey" => "fans_united_styling_tab_content_text_color", "styleProperty" => "--fu-light-tab-content-text-color"],
        // Card styles
        ["optionKey" => "fans_united_styling_card_bg_color", "styleProperty" => "--fu-light-card-bg-color"],
        ["optionKey" => "fans_united_styling_card_title_text_color", "styleProperty" => "--fu-light-card-title-text-color"],
        ["optionKey" => "fans_united_styling_card_text_color", "styleProperty" => "--fu-light-card-text-color"],
        ["optionKey" => "fans_united_styling_card_divider_color", "styleProperty" => "--fu-light-card-divider-color"],
        ["optionKey" => "fans_united_styling_card_padding", "styleProperty" => "--fu-light-card-padding"],
        ["optionKey" => "fans_united_styling_card_shadow", "styleProperty" => "--fu-light-card-shadow"],
        // Market styles
        ["optionKey" => "fans_united_styling_market_bg_color", "styleProperty" => "--fu-light-market-bg-color"],
        ["optionKey" => "fans_united_styling_market_border_color", "styleProperty" => "--fu-light-market-border-color"],
        ["optionKey" => "fans_united_styling_market_text_color", "styleProperty" => "--fu-light-market-text-color"],
        ["optionKey" => "fans_united_styling_market_control_bg_color", "styleProperty" => "--fu-light-market-control-bg-color"],
        ["optionKey" => "fans_united_styling_market_control_input_bg_color", "styleProperty" => "--fu-light-market-control-input-bg-color"],
        ["optionKey" => "fans_united_styling_market_control_input_text_color", "styleProperty" => "--fu-light-market-control-input-text-color"],
        ["optionKey" => "fans_united_styling_market_option_selected_bg_color", "styleProperty" => "--fu-light-market-control-selected-bg-color"],
        ["optionKey" => "fans_united_styling_market_option_selected_border_color", "styleProperty" => "--fu-light-market-control-selected-border-color"],
        ["optionKey" => "fans_united_styling_market_option_selected_text_color", "styleProperty" => "--fu-light-market-control-selected-text-color"],

        // Dark Tab Styles
        ["optionKey" => "fans_united_dark_styling_tab_bg_color", "styleProperty" => "--fu-dark-tab-bg-color"],
        ["optionKey" => "fans_united_dark_styling_tab_text_color", "styleProperty" => "--fu-dark-tab-text-color"],
        ["optionKey" => "fans_united_dark_styling_active_tab_bg_color", "styleProperty" => "--fu-dark-active-tab-bg-color"],
        ["optionKey" => "fans_united_dark_styling_active_tab_text_color", "styleProperty" => "--fu-dark-active-tab-text-color"],
        ["optionKey" => "fans_united_dark_styling_tab_content_bg_color", "styleProperty" => "--fu-dark-tab-content-bg-color"],
        ["optionKey" => "fans_united_dark_styling_tab_content_text_color", "styleProperty" => "--fu-dark-tab-content-text-color"],
        // Dark Card styles
        ["optionKey" => "fans_united_dark_styling_card_bg_color", "styleProperty" => "--fu-dark-card-bg-color"],
        ["optionKey" => "fans_united_dark_styling_card_title_text_color", "styleProperty" => "--fu-dark-card-title-text-color"],
        ["optionKey" => "fans_united_dark_styling_card_text_color", "styleProperty" => "--fu-dark-card-text-color"],
        ["optionKey" => "fans_united_dark_styling_card_divider_color", "styleProperty" => "--fu-dark-card-divider-color"],
        // Dark Market styles
        ["optionKey" => "fans_united_dark_styling_market_bg_color", "styleProperty" => "--fu-dark-market-bg-color"],
        ["optionKey" => "fans_united_dark_styling_market_border_color", "styleProperty" => "--fu-dark-market-border-color"],
        ["optionKey" => "fans_united_dark_styling_market_text_color", "styleProperty" => "--fu-dark-market-text-color"],
        ["optionKey" => "fans_united_dark_styling_market_control_bg_color", "styleProperty" => "--fu-dark-market-control-bg-color"],
        ["optionKey" => "fans_united_dark_styling_market_control_input_bg_color", "styleProperty" => "--fu-dark-market-control-input-bg-color"],
        ["optionKey" => "fans_united_dark_styling_market_control_input_text_color", "styleProperty" => "--fu-dark-market-control-input-text-color"],
        ["optionKey" => "fans_united_dark_styling_market_option_selected_bg_color", "styleProperty" => "--fu-dark-market-control-selected-bg-color"],
        ["optionKey" => "fans_united_dark_styling_market_option_selected_border_color", "styleProperty" => "--fu-dark-market-control-selected-border-color"],
        ["optionKey" => "fans_united_dark_styling_market_option_selected_text_color", "styleProperty" => "--fu-dark-market-control-selected-text-color"],
    ];

    foreach($stylePropertyOptionMap as $pair) {
        if(!empty($fans_united_options[$pair['optionKey']])) {
            $styleString .= 'document.documentElement.style.setProperty(\''.$pair['styleProperty'].'\', \''.$fans_united_options[$pair['optionKey']] .'\');';
        }
    }

    return $styleString;
}

function get_plugin_version() {
    return FANSUNITED_PLUGIN_VERSION;
}

/** 
 * Include frontend script
 */
function enqueue_frontend_scripts() {
    $plugin_version = get_plugin_version();
    wp_enqueue_script('fans-united-frontend', FANSUNITED_PLUGIN_URI . 'frontend-build/fans-united-frontend-' . $plugin_version . '.js', ['wp-element', 'fans-united-auth'], null, true);
}
add_action('wp_enqueue_scripts', 'enqueue_frontend_scripts');
add_action('admin_enqueue_scripts', 'enqueue_frontend_scripts'); // For the management widgets


/**
 * Include styles
 */
function enqueue_custom_styles() {
    wp_enqueue_style( 'fans-united-frontend', FANSUNITED_PLUGIN_URI . 'frontend-build/style-fans-united-frontend.css', array(), '1.0.0', 'all' );
    wp_enqueue_style( 'toastrcss', 'https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.css', array(), '2.1.3', 'all' );
}
add_action('wp_enqueue_scripts', 'enqueue_custom_styles');


// include the frontend styles in the admin for the pages where fans united management tools are called
function enqueue_my_admin_styles() {
    global $pagenow;

    $allowed_slugs = array( 'fu-top-games', 'fu-match-quizzes', 'fu-leaderboards', 'fu-classic-quizzes', 'fu-discussions' );

    if ( $pagenow === 'admin.php' && isset( $_GET['page'] ) && in_array( $_GET['page'], $allowed_slugs ) ) {
        wp_enqueue_style( 'fans-united-frontend', FANSUNITED_PLUGIN_URI . 'frontend-build/style-fans-united-frontend.css', array(), '1.0.0', 'all' );
    }
}
add_action( 'admin_enqueue_scripts', 'enqueue_my_admin_styles' );

