<?php

require_once plugin_dir_path(__FILE__) . 'partials/settings/fans-united-settings-sections.php';
require_once plugin_dir_path(__FILE__) . 'partials/settings/fans-united-settings-fu-fields.php';
require_once plugin_dir_path(__FILE__) . 'partials/settings/fans-united-settings-firebase-fields.php';
require_once plugin_dir_path(__FILE__) . 'partials/settings/fans-united-settings-urls.php';
require_once plugin_dir_path(__FILE__) . 'partials/settings/fans-united-settings-styling-fields.php';


function fans_united_settings_field_validate($input) {
    // other validations...

    // Checkbox value handling
    $input['fans_united_fb_login_enabled'] = isset($input['fans_united_fb_login_enabled']) ? 1 : 0;
    $input['fans_united_google_login_enabled'] = isset($input['fans_united_google_login_enabled']) ? 1 : 0;
    $input['fans_united_use_only_full_coverage_competitions'] = isset($input['fans_united_use_only_full_coverage_competitions']) ? 1 : 0;

    return $input; // return validated and sanitized array
}


/**
 * Register a plugin config page with a menu link
 */
function fansUnitedAddAdminMenu() {
    add_options_page(
        'Fans United Settings', // Page title
        'Fans United', // Menu title
        'manage_options', // Capability required to access the page
        'fans-united', // Menu slug
        'fans_united_settings_page' // Function to display the settings page content
    );
    register_setting('fans_united_settings', 'fans_united_options', 'fans_united_settings_field_validate');
}
add_action('admin_menu', 'fansUnitedAddAdminMenu');

function fans_united_settings_page() {
    ?>
    <div class="wrap">
        <h1>Fans United Settings</h1>
        <style>
            #fans-united-settings .form-table {
                border-bottom: 1px solid #ccc;
                margin: 10px 0;
            }
            #fans-united-settings h2 {
                margin: 50px 0 5px 0;
                font-size: 18px;
                font-weight: bold;
            }
        </style>
        <form action="options.php" method="post" id="fans-united-settings">
            <?php
            settings_fields('fans_united_settings');
            do_settings_sections('fans_united');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}


/**
 * Register a config page for fans united labels
 */
function fansUnitedAddLabelsMenu() {
    add_options_page(
        'Fans United Labels', // Page title
        'Fans United Labels', // Menu title
        'manage_options', // Capability required to access the page
        'fans-united-labels', // Menu slug
        'fans_united_labels_page' // Function to display the settings page content
    );
    register_setting('fans_united_settings', 'fans_united_options', 'fans_united_settings_field_validate');
}
add_action('admin_menu', 'fansUnitedAddLabelsMenu');

function fans_united_labels_page() {
    // Fetching the available languages from the options
    $options = get_option('fans_united_options', []);
    $saved_languages = $options['fans_united_available_languages'] ?? [];
    $all_languages = array(
        'en' => 'English',
        'es' => 'Spanish',
        'fr' => 'French',
        'de' => 'German',
        'it' => 'Italian',
        'pt' => 'Portuguese',
        'sv' => 'Swedish',
        'da' => 'Danish',
        'fi' => 'Finnish',
        'bg' => 'Bulgarian',
        'ro' => 'Romanian',
        'el' => 'Greek',
        'pl' => 'Polish',
        'uk' => 'Ukrainian',
        'ru' => 'Russian',
        'ar' => 'Arabic',
        'ja' => 'Japanese',
        'sw' => 'Swahili',
    );
    $supported_languages = [];
    foreach ($saved_languages as $code) {
        $supported_languages[$code] = $all_languages[$code]; // You might want to map these to actual language names
    }

    // If the form is submitted
    if (isset($_POST['fans_united_labels_submit'])) {
        $selected_language = $_POST['selected_language'];
        $labels_for_language = $_POST['fans_united_labels'];
        
        // Get the existing labels from the option
        $all_labels = get_option('fans_united_labels', []);
        
        // Update the labels for the selected language
        $all_labels[$selected_language] = $labels_for_language;
        
        // Update the option in the database
        update_option('fans_united_labels', $all_labels);
        
        echo '<div class="notice notice-success"><p>Labels updated successfully.</p></div>';
    }

    $selected_language = $_GET['selected_language'] ?? 'default';
    $all_labels = get_option('fans_united_labels', []);
    
    $labels_for_current_language = $all_labels[$selected_language] ?? [];
    $labels = array_merge(FANSUNITED_DEFAULT_LABELS, $labels_for_current_language);
    ?>

    <div class="wrap">
        <h1>Fans United Labels</h1>
        <form method="post">
            <label for="language-selection">Select Language: </label>
            <select id="language-selection" name="selected_language" onchange="location.href='?page=fans-united-labels&selected_language=' + this.value;">
                <option value="default">Default</option>
                <?php foreach ($supported_languages as $code => $name) : ?>
                    <option value="<?php echo esc_attr($code); ?>" <?php selected($code, $selected_language); ?>><?php echo esc_html($name); ?></option>
                <?php endforeach; ?>
            </select>
            
            <table style="border: none;">
            <?php foreach ($labels as $key => $value) : ?>
                <tr>
                    <td><label for="label-<?php echo $key; ?>"><?php echo $key; ?></label></td>
                    <td><input type="text" id="label-<?php echo $key; ?>" name="fans_united_labels[<?php echo $key; ?>]" value="<?php echo esc_attr($value); ?>" style="min-width: 400px;"></td>
                </tr>
            <?php endforeach; ?>
            </table>

            <input type="submit" name="fans_united_labels_submit" value="Save Labels" class="button-primary">
        </form>
    </div>
    <?php
}
