<?php

function fu_register_anonymous_data_routes() {
    register_rest_route('fans-united/v1', '/get-anonymous-game-data', array(
        'methods' => 'GET',
        'callback' => 'fetch_anonymous_data',
        'permission_callback' => 'check_if_user_is_admin',
        'args' => array(
            'game_id' => array(
                'required' => true,
                'validate_callback' => function($param, $request, $key) {
                    return ctype_alnum($param);
                }
            ),
            'profile_ids' => array(
                'required' => true
            )
        )
    ));
}

add_action('rest_api_init', 'fu_register_anonymous_data_routes');


function check_if_user_is_admin(WP_REST_Request $request) {
    
    $nonce = $request->get_param('_wpnonce');
    if (!wp_verify_nonce($nonce, 'wp_rest')) {
        return false;
    }

    if (!is_user_logged_in()) {
        return false;
    }

    $current_user = wp_get_current_user();
    if (in_array('administrator', $current_user->roles)) {
        return true;
    }

    return false;
}


function fetch_anonymous_data(WP_REST_Request $request) {
    global $wpdb;

    $game_id = $request->get_param('game_id');
    $profile_ids_csv = $request->get_param('profile_ids');

    // Explode the CSV string into an array
    $profile_ids = explode(',', $profile_ids_csv);

    // Sanitize each profile ID to ensure safety against SQL injections
    $profile_ids = array_map('sanitize_text_field', $profile_ids);

    $table_name = $wpdb->prefix . 'fu_game_participations';

    // Prepare the SQL statement
    $sql = $wpdb->prepare(
        "SELECT * FROM $table_name WHERE game_id = %s AND profile_id IN (" . implode(',', array_fill(0, count($profile_ids), '%s')) . ")",
        array_merge([$game_id], $profile_ids)
    );

    // Execute the SQL statement
    $data = $wpdb->get_results($sql);

    return new WP_REST_Response(['success' => true, 'data' => $data], 200);
}

