<?php

function fu_register_prediction_routes() {
    register_rest_route('fans-united/v1', '/save-game-participation', array(
        'methods' => 'POST',
        'callback' => 'save_prediction',
        'permission_callback' => 'check_prediction_permissions',
        'args' => array(
            'prediction_id' => array(
                'required' => true,
                'validate_callback' => function($param, $request, $key) {
                    return preg_match('/^[a-zA-Z0-9_]+$/', $param);
                }
            ),
            'game_id' => array(
                'required' => true,
                'validate_callback' => function($param, $request, $key) {
                    return ctype_alnum($param);
                }
            ),
            'user_email' => array(
                'required' => true,
                'validate_callback' => function($param, $request, $key) {
                    return is_email($param);
                }
            ),
            '_wpnonce' => array(
                'required' => true
            )
        )
    ));
}

add_action('rest_api_init', 'fu_register_prediction_routes');


function check_prediction_permissions(WP_REST_Request $request) {
    $nonce = $request->get_param('_wpnonce');
    $is_valid = wp_verify_nonce($nonce, 'save-prediction-nonce');
    error_log("Nonce verification result: " . var_export($is_valid, true));
    return $is_valid;
}

function save_prediction(WP_REST_Request $request) {
    global $wpdb;

    $prediction_id = $request->get_param('prediction_id');
    $prediction_id_exploded = explode("_g_", $prediction_id);
    $profile_id = $prediction_id_exploded[0];
    $game_id = $request->get_param('game_id');
    $user_email = sanitize_email($request->get_param('user_email'));
    $timestamp = current_time('mysql');

    $table_name = $wpdb->prefix . 'fu_game_participations';

    $data = array(
        'prediction_id' => $prediction_id,
        'game_id' => $game_id,
        'profile_id' => $profile_id,
        'user_email' => $user_email,
        'timestamp' => $timestamp
    );

    $format = array('%s', '%s', '%s', '%s');

    // Using REPLACE query
    $wpdb->replace($table_name, $data, $format);

    return new WP_REST_Response(array('success' => true), 200);
}
