<?php

use Firebase\JWT\JWT;
use Firebase\JWT\JWK;

// Register the endpoint
add_action('rest_api_init', 'fu_register_api_hooks');

function fu_register_api_hooks() {
    register_rest_route(
        'fans-united/v1',
        '/sync',
        array(
            'methods'  => 'POST',
            'callback' => 'fu_authenticate_with_firebase',
            'permission_callback' => '__return_true'
        )
    );
}

function fu_authenticate_with_firebase(WP_REST_Request $request) {

    $options = get_option('fans_united_options');
    if((bool) $options['fans_united_sync_users_from_firebase'] !== true) {
        return new WP_REST_Response(array('status' => 'success', 'message' => 'The user has not been synced, since the administrator has not allowed syncing users.'), 200);
    }

    $firebase_token = $request->get_param('token');
    $password = $request->get_param('password');

    $keys = json_decode(file_get_contents('https://www.googleapis.com/service_accounts/v1/jwk/securetoken@system.gserviceaccount.com'), true);
    
    try {
        $decoded = JWT::decode($firebase_token, JWK::parseKeySet($keys), new stdClass(), ['RS256']);

        $email = $decoded->email;

        $user = get_user_by('email', $email);
        
        if (!$user) {
            $user_id = wp_insert_user([
                'user_login' => $email,
                'first_name' => $decoded->name,
                'display_name' => $decoded->nickname ?? $decoded->name,
                'user_email' => $email,
                'user_pass'  => $password ?? wp_generate_password(12, false),
            ]);

            if (is_wp_error($user_id)) {
                return new WP_REST_Response(array('status' => 'error', 'message' => $user_id->get_error_message()), 400);
            }

            update_user_meta($user_id, 'firebase_uid', $decoded->sub);
            $user_to_login = $user_id;
        } else {
            $user_to_login = $user->ID;
        }

        wp_set_auth_cookie($user_to_login);

        return new WP_REST_Response(array('status' => 'success', 'message' => 'User authenticated!'), 200);

    } catch (\Exception $e) {
        return new WP_REST_Response(array('status' => 'error', 'message' => $e->getMessage()), 400);
    }
}
