<?php

use Firebase\JWT\JWT;
use Firebase\JWT\JWK;

// Register the endpoint
add_action('rest_api_init', 'fu_update_password_hooks');

function fu_update_password_hooks() {
    register_rest_route(
        'fans-united/v1',
        '/update-password',
        array(
            'methods'  => 'POST',
            'callback' => 'fu_update_password',
            'permission_callback' => '__return_true'
        )
    );
}

function fu_update_password(WP_REST_Request $request) {
    
    $options = get_option('fans_united_options');
    if((bool) $options['fans_united_sync_users_from_firebase'] !== true) {
        return new WP_REST_Response(array('status' => 'success', 'message' => 'The password has not been updated, since the administrator has not allowed syncing users.'), 200);
    }

    $firebase_token = $request->get_param('token');
    $password = $request->get_param('password');

    $keys = json_decode(file_get_contents('https://www.googleapis.com/service_accounts/v1/jwk/securetoken@system.gserviceaccount.com'), true);
    
    try {
        $decoded = JWT::decode($firebase_token, JWK::parseKeySet($keys), new stdClass(), ['RS256']);

        $email = $decoded->email;

        $user = get_user_by('email', $email);
        
        if ($user) {
            wp_set_password($password, $user->ID);

            // Re-authenticate the user by setting authentication cookies again
            wp_clear_auth_cookie();
            wp_set_current_user($user->ID);
            wp_set_auth_cookie($user->ID);
            return new WP_REST_Response(array('status' => 'success', 'message' => 'Password updated successfully'), 200);
        } else {
            return new WP_REST_Response(array('status' => 'error', 'message' => 'User not found'), 404);
        }

    } catch (\Exception $e) {
        return new WP_REST_Response(array('status' => 'error', 'message' => $e->getMessage()), 400);
    }
}
