<?php

use Firebase\JWT\JWT;
use Firebase\JWT\JWK;

// Register the endpoint
add_action('rest_api_init', 'fu_update_profile_hooks');

function fu_update_profile_hooks() {
    register_rest_route(
        'fans-united/v1',
        '/update-profile',
        array(
            'methods'  => 'POST',
            'callback' => 'fu_update_profile',
            'permission_callback' => '__return_true'
        )
    );
}

function fu_update_profile(WP_REST_Request $request) {
    
    $options = get_option('fans_united_options');
    if((bool) $options['fans_united_sync_users_from_firebase'] !== true) {
        return new WP_REST_Response(array('status' => 'success', 'message' => 'The profile has not been updated, since the administrator has not allowed syncing users.'), 200);
    }

    $firebase_token = $request->get_param('token');
    $displayName = $request->get_param('display_name');
    $nickname = $request->get_param('nickname');

    $keys = json_decode(file_get_contents('https://www.googleapis.com/service_accounts/v1/jwk/securetoken@system.gserviceaccount.com'), true);
    
    try {
        $decoded = JWT::decode($firebase_token, JWK::parseKeySet($keys), new stdClass(), ['RS256']);
        $email = $decoded->email;
        $user = get_user_by('email', $email);
        
        if ($user) {
            // Update the user's display name and nickname
            $update_data = array(
                'ID'           => $user->ID,
                'display_name' => $displayName,
                'first_name'         => $displayName,
                'nickname'     => $nickname,
            );

            $user_id = wp_update_user($update_data);

            if (is_wp_error($user_id)) {
                // There was an error, probably that user doesn't exist
                return new WP_REST_Response(array('status' => 'error', 'message' => 'Error updating user profile'), 500);
            }

            return new WP_REST_Response(array('status' => 'success', 'message' => 'Profile updated successfully'), 200);
        } else {
            return new WP_REST_Response(array('status' => 'error', 'message' => 'User not found'), 404);
        }

    } catch (\Exception $e) {
        return new WP_REST_Response(array('status' => 'error', 'message' => $e->getMessage()), 400);
    }
}
