<?php

/**
 * Fans United fields
 */
function fans_united_client_id_callback() {
    $options = get_option('fans_united_options');
    ?>
    <input type="text" name="fans_united_options[fans_united_client_id]" value="<?php echo esc_attr($options['fans_united_client_id'] ?? ""); ?>">
    <p class="description">What is your Fans United client ID?</p>
    <?php
}

function fans_united_api_key_callback() {
    $options = get_option('fans_united_options');
    ?>
    <input type="text" name="fans_united_options[fans_united_api_key]" value="<?php echo esc_attr($options['fans_united_api_key'] ?? ""); ?>">
    <p class="description">The API key for access to Fans United.</p>
    <?php
}

function fans_united_env_callback() {
    $options = get_option('fans_united_options');
    ?>
    <input type="text" name="fans_united_options[fans_united_env]" value="<?php echo esc_attr($options['fans_united_env'] ?? ""); ?>">
    <p class="description">The Fans United environment for your client. By default "prod" is assumed.</p>
    <?php
}

function fans_united_lang_callback() {
    $options = get_option('fans_united_options');
    ?>
    <input type="text" placeholder="en" name="fans_united_options[fans_united_lang]" value="<?php echo esc_attr($options['fans_united_lang'] ?? ""); ?>">
    <p class="description">The default language (a two-letter, lowercase code) that should be used to return the sprots entities. If a translation is missing, Fans United falls back to English. In case of a multi-lingual website, the user's language preference will override this. The order will be User preference > This language > English fallback.</p>
    <?php
}

function fans_united_available_languages_callback() {
    $options = get_option('fans_united_options');
    
    // Example list of supported languages - replace with actual list
    $supported_languages = array(
        'en' => 'English',
        'es' => 'Spanish',
        'fr' => 'French',
        'de' => 'German',
        'it' => 'Italian',
        'pt' => 'Portuguese',
        'sv' => 'Swedish',
        'da' => 'Danish',
        'fi' => 'Finnish',
        'bg' => 'Bulgarian',
        'ro' => 'Romanian',
        'el' => 'Greek',
        'pl' => 'Polish',
        'uk' => 'Ukrainian',
        'ru' => 'Russian',
        'ar' => 'Arabic',
        'ja' => 'Japanese',
        'sw' => 'Swahili',
    );
    
    // Check which are already selected
    $selected_languages = $options['fans_united_available_languages'] ?? array();

    foreach ($supported_languages as $code => $name) {
        echo '<label><input type="checkbox" name="fans_united_options[fans_united_available_languages][]" value="' . esc_attr($code) . '"' . (in_array($code, $selected_languages) ? ' checked' : '') . '> ' . esc_html($name) . '</label><br>';
    }

    echo '<p class="description">Select the supported languages of your website. If your website is not multi-lingual, don\'t select anything.</p>';
}


function fans_united_id_provider_callback() {
    $options = get_option('fans_united_options');
    ?>
    <input type="text" placeholder="native" name="fans_united_options[fans_united_id_provider]" value="<?php echo esc_attr($options['fans_united_id_provider'] ?? ""); ?>">
    <p class="description">What IDs will you be using for your statistical data? Options include: "native", "sportal365", "enetpuse".</p>
    <?php
}

function fans_united_use_only_full_coverage_competitions_callback() {
    $options = get_option('fans_united_options');
    $checked = isset($options['fans_united_use_only_full_coverage_competitions']) && $options['fans_united_use_only_full_coverage_competitions'] == '1' ? 'checked' : '';
    ?>
    <input type="checkbox" id="fans_united_use_only_full_coverage_competitions" name="fans_united_options[fans_united_use_only_full_coverage_competitions]" value="1" <?php echo $checked; ?>>
    <label for="fans_united_use_only_full_coverage_competitions">Limit requests to full coverage competitions</label>
    <p class="description">If checked, this will apply scope to all requests to the Football API. This means that all responses for football data will be limited only to the competitions in the list with full coverage. You can check the list with full-coverage competitions in you features config in Fans United management portal.</p>
 <?php
}

function fans_united_sync_users_from_firebase_callback() {
    $options = get_option('fans_united_options');
    $checked = isset($options['fans_united_sync_users_from_firebase']) && $options['fans_united_sync_users_from_firebase'] == '1' ? 'checked' : '';
    ?>
    <input type="checkbox" id="fans_united_sync_users_from_firebase" name="fans_united_options[fans_united_sync_users_from_firebase]" value="1" <?php echo $checked; ?>>
    <label for="fans_united_sync_users_from_firebase">Sync users from Firebase</label>
    <p class="description">If checked, each time a user signs in Firebase, their account data (email, name, nickname and password, if available) will be synced to WordPress. This way, the user can use native WP functionalities like comments. Also, all other plugins the client might be using that rely on a WP user, should work seemlessly. If unchecked, only Fans United functionality will work with the registered users.</p>
 <?php
}

function fans_united_wizard_template_for_match_quiz_callback() {
    $options = get_option('fans_united_options');
    $checked = isset($options['fans_united_wizard_template_for_match_quiz']) && $options['fans_united_wizard_template_for_match_quiz'] == '1' ? 'checked' : '';
    ?>
    <input type="checkbox" id="fans_united_wizard_template_for_match_quiz" name="fans_united_options[fans_united_wizard_template_for_match_quiz]" value="1" <?php echo $checked; ?>>
    <label for="fans_united_wizard_template_for_match_quiz">Wizard templates for match quiz</label>
    <p class="description">If checked, the UI for match quizzes will be a wizard (a number of steps for each market with next/prev buttons). If unchecked, the design will be the regular all-on-one-page layout.</p>
 <?php
}



function fansUnitedSettingsInit() {

    /**
     * Fans United settings
     */
    add_settings_field(
        'fans_united_client_id', // Field ID
        'Fans United Client Id', // Field title
        'fans_united_client_id_callback', // Callback function to render the field
        'fans_united', // Page on which to display the field
        'fans_united_section' // Section in which to display the field
    );
    add_settings_field(
        'fans_united_api_key', // Field ID
        'Fans United API Key', // Field title
        'fans_united_api_key_callback', // Callback function to render the field
        'fans_united', // Page on which to display the field
        'fans_united_section' // Section in which to display the field
    );
    add_settings_field(
        'fans_united_lang', // Field ID
        'Fans United Default Language', // Field title
        'fans_united_lang_callback', // Callback function to render the field
        'fans_united', // Page on which to display the field
        'fans_united_section' // Section in which to display the field
    );

    add_settings_field(
        'fans_united_env', // Field ID
        'Fans United Environment', // Field title
        'fans_united_env_callback', // Callback function to render the field
        'fans_united', // Page on which to display the field
        'fans_united_section' // Section in which to display the field
    );
    add_settings_field(
        'fans_united_sync_users_from_firebase', // Field ID
        'Sync Users from Firebase', // Field title
        'fans_united_sync_users_from_firebase_callback', // Callback function to render the field
        'fans_united', // Page on which to display the field
        'fans_united_section' // Section in which to display the field
    );

    add_settings_field(
        'fans_united_available_languages',      // Field ID
        'Fans United Languages',                // Field title
        'fans_united_available_languages_callback', // Callback function to render the field
        'fans_united',                          // Page on which to display the field
        'fans_united_section'                   // Section in which to display the field
    );   

    add_settings_field(
        'fans_united_id_provider', // Field ID
        'Fans United ID Provider', // Field title
        'fans_united_id_provider_callback', // Callback function to render the field
        'fans_united', // Page on which to display the field
        'fans_united_section' // Section in which to display the field
    );

    add_settings_field(
        'fans_united_use_only_full_coverage_competitions', // id
        'Limit to full coverage competitions only',
        'fans_united_use_only_full_coverage_competitions_callback', // callback
        'fans_united', // page
        'fans_united_section' // section
    );

    add_settings_field(
        'fans_united_wizard_template_for_match_quiz', // id
        'Wizard template for Match Quizzes',
        'fans_united_wizard_template_for_match_quiz_callback', // callback
        'fans_united', // page
        'fans_united_section' // section
    );

}
add_action('admin_init', 'fansUnitedSettingsInit');
